Why Program?
:::::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Introduction
   :maxdepth: 3

   why-program.rst
   creativityAndMot.rst
   computerHardwareArch.rst
   understanding.rst
   words-and-sentences.rst
   conversing.rst
   terminology.rst
   writingPrograms.rst
   whatIsAProgram.rst
   buildingBlocks.rst
   goWrong.rst
   debugging.rst
   learning.rst
   glossary.rst
   Exercises.rst
